function [N, S] = Floquet_percolation_dynamics(p0, alpha, q, L, T, Nf, pF)
% p0       Initial probability distribution
% L        System size
% Nt       Number of time steps
% S        State of the system
% q        Parameter of the function f (p = f(phi)), called mu in the paper
% alpha    Exponent of the power law average
% Nf       Number of Floquet periods
% T        Number of steps of each Floquet period
% pF       Probability of doing the Floquet flip right at a given site,
%          equal to 1-pd. (pd = defect probability from the paper).

    IC = double(rand(1, L) < p0); %Initial occupations

    N = []; %Initialization
    S = []; %Initialization of the state variable
    %The subscript op means One Period
    for nf = 1:Nf             %Loop over the Floquet periods
        [N_op, S_op] = percolation_dynamics(IC, alpha, q, L, T); %Evolve for one Floquet period
        
        %Floquet
        doF = double(rand(1, L) < pF);                          %Array of flags that say, per each site, if the Floquet flipping is done or not
        IC = doF.*(1 - S_op(end, :)) + (1-doF).*S_op(end, :);   %Action of the Floquet driving: prepare the IC for the next step

        N = [N; N_op];              %Append the total population time series of the current Floquet period

        if nargout == 2             %Only if needed...
            S = [S; S_op];          %...Append the time series for all the sites
        end
    end
end