%Generates the plot of Nend versus alpha (possibly for various q)
clc; clear all; close all
%% PARAMETERS
Nt = 1000;               %Total number of time steps
L = 100;                 %Number of sites
R = 100;                  %Number of independent runs

alpha_vec = linspace(1, 2.5, 20); %Values of the power-law exponent
q_vec = [0.83:0.01:0.85]; %Parameter of the function f - called mu in the paper

init_type = 'rnd';      %Specifies the type of initialization
                        %'seed' --> only the central site is occupied
                        %'rnd'  --> random occupation of all sites with probability pIC
pIC = 1;             %see line above
%% COMPUTATION
rng(1234);              %Initialization of the random number generator
fig_Nend = figure;      %Open the figure for the plot

%INITIALIZATION of the occupation probabilities p0 at initial time t = 1
switch init_type
    case 'seed'
        p0 = zeros(1,L);        %All sites non occupied
        p0(round(L/2)) = 1;     %Except the initial one
    case 'rnd'
        p0 = pIC*ones(1,L);     %Same probability pIC for all sites
    otherwise
        display('ERROR: invalid init_type')
end

Nalpha     = length(alpha_vec);
Nq         = length(q_vec);
Nend       = NaN*ones(Nq, Nalpha); %Number of particles at final time
nsim       = 1; %Conunter

%Display messages
display('### PLOT NEND VS ALPHA AND Q')
display('Parameters: ')
display(['Nt = ', num2str(Nt)]);
display(['L  = ', num2str(L)]);
display(['R  = ', num2str(R)]);
display(['min alpha = ', num2str(min(alpha_vec))]);
display(['max alpha = ', num2str(max(alpha_vec))]);
display(['Nalpha  = ', num2str(Nalpha)]);
display(['Nq  = ', num2str(Nq)]);
display(['min q = ', num2str(min(q_vec))]);
display(['max q = ', num2str(max(q_vec))]);
display(['Init type = ', init_type]);
display(['pIC = ', num2str(pIC)]);
display(['Computation starts in date ', datestr(datetime)]);
tic

%Computation
for nq = 1:Nq
    for nalpha = 1:Nalpha
        display_progress_bar(nsim, Nalpha*Nq); nsim = nsim+1;
        q = q_vec(nq);
        alpha = alpha_vec(nalpha);

        %Loop over independent realizations
        Nr = zeros(Nt, R); %Initialize variable to store the time series of the various independent runs
        parfor r = 1:R
            Nr(:, r) = percolation_dynamics(p0, alpha, q, L, Nt);
        end
        Nend(nq, nalpha) = mean(Nr(end, :)); %Average number of particles at final time
    end
    figure(fig_Nend);
    p = plot(alpha_vec, Nend/L); xlabel('\alpha'); ylabel('N/L');
    xlim([min(alpha_vec), max(alpha_vec)]); ylim([0,1]);
    hold on;
    
    
    F = @(x) q*tanh(4*x^2)-x;
    xfp = fzero(F, 1);
    hline(xfp, '--');
    %save('Nend');
    drawnow;
end
display(['Computation ends in date ', datestr(datetime)])
display(['Computation time ', num2str(toc), ' s'])