%Generates the plot of Nend in the alpha, q plane
clc; clear all; close all
%% PARAMETERS
Nt = 1000;               %Total number of time steps
L = 500;                 %Number of sites
R = 100;                  %Number of independent runs

alpha_vec = linspace(0, 3, 50);
q_vec = linspace(0.6, 1, 50);

init_type = 'rnd';     %Specifies the type of initialization
                        %'seed' --> only the central site is occupied
                        %'rnd'  --> random occupation of all sites with probability pIC
pIC = 1;                %see line above
%pIC = 0.01;                %see line above
%% COMPUTATION
rng(1234);              %Initialization of the random number generator
fig_Nend = figure;      %Open the figure for the plot

%INITIALIZATION of the occupation probabilities p0 at initial time t = 1
switch init_type
    case 'seed'
        p0 = zeros(1,L);        %All sites non occupied
        p0(round(L/2)) = 1;     %Except the initial one
    case 'rnd'
        p0 = pIC*ones(1,L);     %Same probability pIC for all sites
    otherwise
        display('ERROR: invalid init_type')
end

Nalpha     = length(alpha_vec);     %Number of alpha values to consider
Nq         = length(q_vec);         %Number of q values to consider
Nend       = NaN*ones(Nq, Nalpha);  %Initialize number of particles at final time
[ALPHA, Q] = meshgrid(alpha_vec, q_vec);
nsim       = 1; %Conunter

%Display messages
display('### PLOT NEND VS ALPHA AND Q')
display('Parameters: ')
display(['Nt = ', num2str(Nt)]);
display(['L  = ', num2str(L)]);
display(['R  = ', num2str(R)]);
display(['min alpha = ', num2str(min(alpha_vec))]);
display(['max alpha = ', num2str(max(alpha_vec))]);
display(['Nalpha  = ', num2str(Nalpha)]);
display(['Nq  = ', num2str(Nq)]);
display(['min q = ', num2str(min(q_vec))]);
display(['max q = ', num2str(max(q_vec))]);
display(['Init type = ', init_type]);
display(['pIC = ', num2str(pIC)]);
display(['Computation starts in date ', datestr(datetime)]);
tic

%Computation
for nalpha = 1:Nalpha
    for nq = 1:Nq
        display_progress_bar(nsim, Nalpha*Nq); nsim = nsim+1;
        q = q_vec(nq);
        alpha = alpha_vec(nalpha);

        %Loop over independent realizations
        Nr = zeros(Nt, R); %Initialize variable to store the time series of the various independent runs
        parfor r = 1:R
            Nr(:, r) = percolation_dynamics(p0, alpha, q, L, Nt);
        end
        Nend(nq, nalpha) = mean(Nr(end, :)); %Average number of particles at final time
    end
    figure(fig_Nend);
    surf(ALPHA, Q, Nend/L); view(2); colorbar; colormap(mycolormap([253 255 220; 64 183 195; 5 34 99]/255)); xlabel('\alpha'); ylabel('q'); title('N(end)/L');
    xlim([min(alpha_vec), max(alpha_vec)]); ylim([min(q_vec), max(q_vec)]); caxis([0,1])
    drawnow;
    save(['Nend_p1_', num2str(pIC)]);
    savefig(['Nend_p1_', num2str(pIC), '.fig'])
end
display(['Computation ends in date ', datestr(datetime)])
display(['Computation time ', num2str(toc), ' s'])