%% Mean field percolation DTCs
% Written by Andrea Pizzi - 12/05/2020 - Cambridge UK

close all; clear all; clc

%% Parameters
mu = 0.65;
T = 10;             %Period
Ncw = 100;          %Number of periods for the cobwebs
toll = 1e-8;        %Tolerance for the FP finder
Nitermax = 1e6;     %Maximum number of iterations for the FP finder
%% Computation
display('Perc11 - discrete map analysis and cowbeds')

fig = figure;
p = linspace(0,1,200); %Vector of occupation probabilities

f = FloquetMFdynamics(p, mu, T);
f2 = FloquetMFdynamics(f, mu, T);

FPs = twoTmapFP(mu, T, toll, Nitermax); %Find the fixed points

%One year map
p1cw = 0;  %Initial fraction of infected people
%cobwebx and cobweby contain the coordinates of the corners of the cobweb
cobwebx = [p1cw];
cobweby = [0];
for n = 1:Ncw-1
    p1cw = FloquetMFdynamics(p1cw, mu, T);
    %Add the two points to the cobweb
    cobwebx = [cobwebx; cobwebx(end)];
    cobweby = [cobweby; p1cw];
    cobwebx = [cobwebx; p1cw];
    cobweby = [cobweby; cobweby(end)];
end

subplot(1,2,1);
plot([0,1], [0,1], 'k--'); hold on
plot(cobwebx, cobweby, 'b');
plot(p, f, 'r');
xlabel('p_1'); ylabel('f');
title('One year map')

if isnan(FPs(1))
    %There is only one stable FP
    scatter(FPs(2), FPs(2), 'r', 'MarkerFaceColor', 'r'); %Stable FP
else
    scatter(FPs(1), FPs(1), 'r', 'MarkerFaceColor', 'r'); %Stable FP
    scatter(FPs(2), FPs(2), 'r', 'MarkerFaceColor', 'none'); %Unstable FP
    scatter(FPs(3), FPs(3), 'r', 'MarkerFaceColor', 'r'); %Stable FP
end


%Two years map
p1cw = 0;  %Initial fraction of infected people
%cobwebx and cobweby contain the coordinates of the corners of the cobweb
cobwebx = [p1cw];
cobweby = [0];
for n = 1:Ncw-1
    p1cw = FloquetMFdynamics(p1cw, mu, T); %Infected people at the end of the first winter
    p1cw = FloquetMFdynamics(p1cw, mu, T); %Infected people at the end of the second winter
    %Add the two points to the cobweb
    cobwebx = [cobwebx; cobwebx(end)];
    cobweby = [cobweby; p1cw];
    cobwebx = [cobwebx; p1cw];
    cobweby = [cobweby; cobweby(end)];
end

subplot(1,2,2);
plot([0,1], [0,1], 'k--'); hold on
plot(cobwebx, cobweby, 'b');
plot(p, f2, 'r');
xlabel('p_1'); ylabel('f^2');
title('Two years map')

if isnan(FPs(1))
    %There is only one stable FP
    scatter(FPs(2), FPs(2), 'r', 'MarkerFaceColor', 'r'); %Stable FP
else
    scatter(FPs(1), FPs(1), 'r', 'MarkerFaceColor', 'r'); %Stable FP
    scatter(FPs(2), FPs(2), 'r', 'MarkerFaceColor', 'none'); %Unstable FP
    scatter(FPs(3), FPs(3), 'r', 'MarkerFaceColor', 'r'); %Stable FP
end