%Generates the plot of Nend in the alpha, pIC plane
clc; clear all; close all
%% PARAMETERS
Nt = 1000;               %Total number of time steps
L = 500;                 %Number of sites
R = 100;                  %Number of independent runs

alpha_vec = linspace(0, 3, 50); %Values of the power-law exponent
pIC_vec = linspace(1/L, 1, 50); %Initial occupation probability, called p1 in the paper
q = 0.9;                 %Value of the control parameter (called mu in the paper)
%% COMPUTATION
rng(1234);              %Initialization of the random number generator
fig_Nend = figure;      %Open the figure for the plot

Nalpha     = length(alpha_vec); %Number of values of the power-law exponent
NpIC       = length(pIC_vec);   %Number of vaues of the initial occupation probability
Nend       = NaN*ones(NpIC, Nalpha); %Number of particles at final time
[ALPHA, PIC] = meshgrid(alpha_vec, pIC_vec);
nsim       = 1; %Conunter

%Display messages
display('### PLOT NEND VS ALPHA AND pICQ')
display('Parameters: ')
display(['Nt = ', num2str(Nt)]);
display(['L  = ', num2str(L)]);
display(['R  = ', num2str(R)]);
display(['min alpha = ', num2str(min(alpha_vec))]);
display(['max alpha = ', num2str(max(alpha_vec))]);
display(['Nalpha = ', num2str(Nalpha)]);
display(['NpIC  = ', num2str(NpIC)]);
display(['min pIC = ', num2str(min(pIC_vec))]);
display(['max pIC = ', num2str(max(pIC_vec))]);
display(['Computation starts in date ', datestr(datetime)]);
tic

%Computation
for nalpha = 1:Nalpha
    for npIC = 1:NpIC
        display_progress_bar(nsim, Nalpha*NpIC); nsim = nsim+1;
        pIC = pIC_vec(npIC);
        alpha = alpha_vec(nalpha);

        %Loop over independent realizations
        Nr = zeros(Nt, R); %Initialize variable to store the time series of the various independent runs
        parfor r = 1:R
            Nr(:, r) = percolation_dynamics(pIC, alpha, q, L, Nt);
        end
        Nend(npIC, nalpha) = mean(Nr(end, :)); %Average number of particles at final time
    end
    figure(fig_Nend);
    surf(ALPHA, PIC, Nend/L); view(2); colorbar; colormap(mycolormap([253 255 220; 64 183 195; 5 34 99]/255)); xlabel('\alpha'); ylabel('p_{IC}'); title('N(end)/L');
    xlim([min(alpha_vec), max(alpha_vec)]); ylim([min(pIC_vec), max(pIC_vec)]); caxis([0,1])
    
    save(['Nend_mu_', num2str(q)]);
    savefig(['Nend_mu_', num2str(q), '.fig'])
end
display(['Computation ends in date ', datestr(datetime)])
display(['Computation time ', num2str(toc), ' s'])