%Generates the plot of the time series of <N(t)>
clc; clear all; close all
%% PARAMETERS
Nt = 2000;               %Total number of time steps
L = 500;                 %Number of sites
R = 10000;                  %Number of independent runs

alpha_vec = [2,1.7,2];    %Values of the power-law exponent
q_vec = [0.845, 0.855, 0.875]; %Vaues of the control parameter (called mu in the paper)
%q_vec = 0.9;

init_type = 'rnd';     %Specifies the type of initialization
                        %'seed' --> only the central site is occupied
                        %'rnd'  --> random occupation of all sites with
                        %probability pIC (called p1 in the paper)
pIC_vec = [0.01, 1];    %see line above
%% COMPUTATION
rng(1234);              %Initialization of the random number generator
fig_N = figure;      %Open the figure for the plot

Nalpha     = length(alpha_vec); %Number of values of the power-law exponent
Nq         = length(q_vec);     %Number of values of the conrtol parameter (called mu in the paper).

%Display messages
display('### PLOT <N(t)>')
display('Parameters: ')
display(['Nt = ', num2str(Nt)]);
display(['L  = ', num2str(L)]);
display(['R  = ', num2str(R)]);
display(['min alpha = ', num2str(min(alpha_vec))]);
display(['max alpha = ', num2str(max(alpha_vec))]);
display(['Nalpha  = ', num2str(Nalpha)]);
display(['Nq  = ', num2str(Nq)]);
display(['min q = ', num2str(min(q_vec))]);
display(['max q = ', num2str(max(q_vec))]);
display(['Init type = ', init_type]);
display(['pIC = ', num2str(pIC_vec)]);
display(['Computation starts in date ', datestr(datetime)]);
tic

%Computation
for pIC = pIC_vec
    %INITIALIZATION of the occupation probabilities p0 at initial time t = 1
    switch init_type
        case 'seed'
            p0 = zeros(1,L);        %All sites non occupied
            p0(round(L/2)) = 1;     %Except the initial one
        case 'rnd'
            p0 = pIC*ones(1,L);     %Same probability pIC for all sites
        otherwise
            display('ERROR: invalid init_type')
    end
    
    for nsim = 1:Nalpha
        display_progress_bar(nsim, Nalpha);
        q = q_vec(nsim);
        alpha = alpha_vec(nsim);

        %Loop over independent realizations
        Nr = zeros(Nt, R); %Initialize variable to store the time series of the various independent runs
        parfor r = 1:R
            Nr(:, r) = percolation_dynamics(p0, alpha, q, L, Nt);
        end
        N = mean(Nr,2); %Average number of particles at final time

        figure(fig_N);
        if pIC > 0.5
            subplot(1,2,2);
            p = semilogx(N/L); ylim([0,1]); hold on;
            p.LineStyle = '--';
            ylabel('\langle N \rangle/L'); xlabel('Time'); xlim([1, Nt]);
        else
            subplot(1,2,1);
            p = loglog(N/L); hold on;
            p.LineStyle = '-';
            ylabel('\langle N \rangle/L'); xlabel('Time'); xlim([1, Nt]);
        end
        savefig('N_vs_t.fig');
        drawnow;
        %save('Nend');
    end
end
display(['Computation ends in date ', datestr(datetime)])
display(['Computation time ', num2str(toc), ' s'])