clc; clear all; close all
Nt = 1000;               %Total number of time steps
L = 500;                 %Number of sites
alpha = 200;             %Power-law exponent
q = 0.86;                %Control parameter (called mu in the paper)

init_type = 'rnd';     %Specifies the type of initialization
                        %'seed' --> only the central site is occupied
                        %'rnd'  --> random occupation of all sites with probability pIC
pIC = 0.02;                %see line above

%INITIALIZATION of the occupation probabilities p0 at initial time t = 1
switch init_type
    case 'seed'
        p0 = zeros(1,L);        %All sites non occupied
        p0(round(L/2)) = 1;     %Except the initial one
    case 'rnd'
        p0 = pIC*ones(1,L);     %Same probability pIC for all sites
    otherwise
        display('ERROR: invalid init_type')
end

%Plot single realizations
for r = [1:100]
    rng(r); r
    [N, S] = percolation_dynamics(p0, alpha, q, L, Nt);
    for t = 1:Nt; Striang(t, :) = circshift(S(t,:), ceil(t/2)); end %Make the matrix look like the original triangular lattice
    surf(Striang); xlabel('j'); ylabel('t'); colormap(mycolormap('wk')); view(2); shading 'flat'; drawnow;
    pause;
end