%Model: Domany - Kinzel Cellular Automation
%       periodic boundary conditions

%The state of the site j at time t is in the variable S(t, j). S basically
%is the "sheared" state, so that the lattice becomes squared and can be
%directly encoded in a matrix.

clc; clear all; close all
%% PARAMETERS
p1_vec = linspace(0.5,1,100);  %Values of the first probability parameter for the DK model
p2_vec = linspace(0.01,1,100); %Values of the second probability parameter for the DK model
Nt = 1000;   %Total number of time steps
L = 100;     %Number of sites (you can consider larger systems with PBC then)
R = 1000;      %Number of independent runs
%% COMPUTATION

%Piece of code to generate the line corresponding to the path that you can
%follow in the p1,p2 plane with the function f (this line appear in
%Supplementary Fig. 2).
% delta_vec = linspace(0.75, 1, 100);
% p1 = []; p2 = [];
% for ndelta = 1:length(delta_vec)
%     delta = delta_vec(ndelta);
%     phi = 0.5;    p1(end+1) = delta*tanh(4*phi^2);
%     phi = 1;      p2(end+1) = delta*tanh(4*phi^2);
% end
% figure;
% p = plot3(p1, p2, 1.1*ones(size(p1))); xlim([min(p1_vec), max(p1_vec)]); ylim([min(p2_vec), max(p2_vec)]);
% cd = [uint8(jet(100)*255) uint8(ones(100,1))].';
% set(p.Edge, 'ColorBinding','interpolated', 'ColorData',cd); drawnow
% p.LineWidth = 4;
% hold on;


rng(1234);      %Initialization of the random number generator
Np1 = length(p1_vec);
Np2 = length(p2_vec);
[P1, P2] = meshgrid(p1_vec, p2_vec);
Nend = NaN*ones(size(P1));%Initialize
nsim = 1;
for np2 = 1:Np2
    for np1 = 1:Np1
        p1 = p1_vec(np1);
        p2 = p2_vec(np2);
        display_progress_bar(nsim,Np1*Np2);
        
        %Loop over independent realizations        
        N = zeros(Nt, R); %Initialization of the variable storing the time series of the occupation for each run
        parfor r = 1:R
            S = zeros(Nt, L); %Initialization
            %display_progress_bar(r, R);
            %Initialization of the probabilities of filling the various sites at initial time t = 1
            %ptj = zeros(1,L); ptj(round(L/2)) = 1; %Occupy the central site only...
            ptj = ones(1,L);                        %... or occupy all sites
            S(1, :) = double(rand(1, L) < ptj); %Initial generation

            %Loop over time steps
            for t = 2:Nt
                for j = 1:L
                    switch S(t-1, j) + S(t-1, mod(j, L)+1) %The mod implements PBC
                        case 2
                            S(t, j) = double(rand < p2); %Possibly occupy site in the next generation
                        case 1     
                            S(t, j) = double(rand < p1); %Possibly occupy site in the next generation
                        case 0
                            S(t, j) = 0; %Do not occupy a site in the next generation
                    end
                end
            end
            NendR(r) = sum(S(end, :)); %Store the total occupation at final time for each independent run. Sum over sites

            %N = sum(S, 2);
            %p = polyfit(log([1:Nt])', log(N), 1);
            %theta = p(1); %Power law exponent
        end
        
        Nend(np2, np1) = mean(NendR); %Average over the independent realizations
        
        if mod(nsim, 50) == 0 | nsim == Np1*Np2
            surf(P1, P2, Nend/L); shading 'flat'; view(2); title('\langle N \rangle/L'); xlabel('p_1'); ylabel('p_2')
            colormap(mycolormap([253 255 220; 64 183 195; 5 34 99]/255)); caxis([0,1]); colorbar;
            xlim([min(p1_vec), max(p1_vec)]); ylim([min(p2_vec), max(p2_vec)]);
            drawnow
        end
        
        nsim = nsim + 1;
    end %End loop over p2
    save('DK');
end %End loop over p1