%Code that plots the time series <N(t)/L>
clc; clear all; close all
%% PARAMETERS
T = 20;                %Floquet period
L = 500;               %Number of sites
Nf = 40;               %Number of Floquet steps
R = 2000;              %Number of independent runs
pF = 0.98;             %Probability of doing the Floquet flips right (that is, 1-pd, with pd the defect probability used in the main)
alpha = 1.8;           %Power law exponent
q = 0.9;               %Parameter of the function f (called mu in the paper)
init_type = 'rnd';     %Specifies the type of initialization. Either 'rnd' (with probability pIC), or 'seed' (with just the central site being occupied
pIC = 1;               %see line above (called p1 in the paper)
%% COMPUTATION
rng(1234);              %Initialization of the random number generator

%INITIALIZATION of the occupation probabilities p0 at initial time t = 1
switch init_type
    case 'seed'
        p0 = zeros(1,L);        %All sites non occupied
        p0(round(L/2)) = 1;     %Except the initial one
    case 'rnd'
        p0 = pIC*ones(1,L);     %Same probability pIC for all sites
    otherwise
        display('ERROR: invalid init_type')
end

fig_Nvst = figure;

%Display messages
display('### FLOQUET COMPUTATION')
display('Parameters: ')
display(['T = ', num2str(T)]);
display(['Nf = ', num2str(Nf)]);
display(['L  = ', num2str(L)]);
display(['R  = ', num2str(R)]);
display(['PF = ', num2str(pF)]);
display(['alpha = ', num2str(alpha)]);
display(['q = ', num2str(q)]);
display(['Init type = ', init_type]);
display(['pIC = ', num2str(pIC)]);
display(['Computation starts in date ', datestr(datetime)]);
tic

%Loop over independent realizations

%I break the independet runs in group of K runs, that are then performed
%with the parfor.
K = 100;                 %Number of independent runs that are run on the parfor
R = round(R/K)*K;       %Rund R to be a multiple of K
Nr = zeros(T*Nf, R);    %Initialize variable to store the time series of the various independent runs

for k = 1:R/K
    display_progress_bar(k, R/K);
    parfor r = (k-1)*K+1:k*K
        Nr(:, r) = Floquet_percolation_dynamics(p0, alpha, q, L, T, Nf, pF);
    end
    r = k*K; %Number of already computed independent runs 
    N = mean(Nr(:, [1:r]), 2); %Average number of particles at final time
    figure(fig_Nvst);
    plot([1:T*Nf]', N/L); xlabel('Time t'); ylabel('\langle N(t)/L \rangle'); title(['r = ', num2str(r)]);
    drawnow;
end

display(['Computation ends in date ', datestr(datetime)])
display(['Computation time ', num2str(toc), ' s'])