%Code that plots single instances of the Floquet percolation
clc; clear all; close all
%% PARAMETERS
T = 20;                 %Floquet period
L = 500;                %Number of sites
Nf = 40;                %Number of Floquet steps
pF = 0.98;              %Probability of doing the Floquet flips right (that is, 1-pd, with pd the defect probability used in the paper)
alpha = 1.4;            %Power law exponent
q = 0.9;                %Parameter of the function f (called mu in the paper)
init_type = 'rnd';      %Specifies the type of initialization. Either 'rnd' (with probability pIC), or 'seed' (with just the central site being occupied
pIC = 1;                %see line above (called p1 in the paper)
%% COMPUTATION

%INITIALIZATION of the occupation probabilities p0 at initial time t = 1
switch init_type
    case 'seed'
        p0 = zeros(1,L);        %All sites non occupied
        p0(round(L/2)) = 1;     %Except the initial one
    case 'rnd'
        p0 = pIC*ones(1,L);     %Same probability pIC for all sites
    otherwise
        display('ERROR: invalid init_type')
end

Nt = T*Nf; %Total number of time steps
for r = 1:100
    r
    rng(r);              %Initialization of the random number generator
    [N, S] = Floquet_percolation_dynamics(p0, alpha, q, L, T, Nf, pF);
    for t = 1:Nt; Striang(t, :) = circshift(S(t,:), ceil(t/2)); end %Make the matrix look like the original triangular lattice
    figure
    surf(Striang'); xlabel('j'); ylabel('t'); colormap(mycolormap('wk')); view(2); shading 'flat';
    drawnow; pause;
end